import QtQuick 2.0
import Ubuntu.Components 1.1
import Ubuntu.Components.Popups 1.0
import Ubuntu.Content 0.1
import com.nogzatalz.Downow 1.0
import "components"
import "Utils.js" as Utils
import QtMultimedia 5.0

MainView {
    id: root

    // objectName for functional testing purposes (autopilot-qt5)
    objectName: "mainView"

    // Note! applicationName needs to match the "name" field of the click manifest
    applicationName: "com.nogzatalz.downow"

    automaticOrientation: true
    anchorToKeyboard: true

    width: Utils.gu(40)
    height: width * 16 / 9

    property DowNowTheme theme: whiteTheme

    DowNowTheme {
        id: darkTheme
        backgroundColor: "#3f3f3f"
        textColor: "#fff"
        progressIndicatorDownloadingColor: "#20a800"
        progressIndicatorPausedColor: "#ddd"
        progressIndicatorDoneColor: "#20a800"
    }

    DowNowTheme {
        id: whiteTheme
        backgroundColor: "#eee"
        textColor: "#666"
        torrentTitleColor: "#555"
        progressIndicatorDownloadingColor: "#20a800"
        progressIndicatorPausedColor: "#ddd"
        progressIndicatorDoneColor: progressIndicatorDownloadingColor
        torrentDownloadSpeedTextColor: Qt.darker(textColor, 1.1)
        torrentUploadSpeedTextColor: torrentDownloadSpeedTextColor
    }

    backgroundColor: theme.backgroundColor

    useDeprecatedToolbar: false

    Action {
        id: addAction
        text: "Add"
        iconName: "add"
        onTriggered: {
            pageStack.push(searchPage)
        }
    }

    Audio {
        id: doneSound
        source: "sounds/done.ogg"
    }

    Connections {
        target: globalSession
        onTorrentCompleted: {
            doneSound.play()
        }
        onDuplicateTorrentError: {
            PopupUtils.open(duplicateTorrentDialogComponent, root, {torrentName: name})
        }
    }

    Connections {
        target: app
        onSelectPeerForContentType: {
            PopupUtils.open(peerPickerPopupComponent, root, {contentType: contentType})
        }

        onShowNoDestinationForType: {
            PopupUtils.open(cantOpenFileComponent, root)
        }
    }

    PageStack {
        id: pageStack
        Component.onCompleted: push(tabs)

        Tabs {
            id: tabs
            visible: false

            Tab {
                title: page.title
                page: TorrentListPage {
                    id: torrentListPage
                    theme: root.theme
                    addAction: addAction

                    onOpenTorrentDetailsPage: {
                        pageStack.push(torrentPageComponent, {
                            torrent: torrent
                        });
                    }
                }
            }

            Tab {
                title: page.title
                page: AboutPage {}
            }
        }

        SearchPage {
            id: searchPage
            visible: false
            pageStack: pageStack
            onTorrentLinkSelected: {
                globalSession.addTorrentByMagnetLink(magnetLink)
            }
            onTorrentFileSelected: {
                globalSession.addTorrentByFile(torrentFilePath)
            }
            onSelectedTorrent: {
                pageStack.pop()
            }
        }
    }

    Component {
        id: torrentPageComponent
        TorrentPage {
            theme: root.theme
            onDone: pageStack.pop()
        }
    }

    Component {
        id: peerPickerPopupComponent
        PopupBase {
            id: popup
            property alias contentType: peerPicker.contentType

            ContentPeerPicker {
                id: peerPicker
                handler: ContentHandler.Destination

                onPeerSelected: {
                    app.onSelectedPeerWithAppId(peer.appId)
                    PopupUtils.close(popup)
                }

                onCancelPressed: {
                    app.onSelectPeerCanceled()
                    PopupUtils.close(popup)
                }
            }
        }
    }

    Component {
        id: cantOpenFileComponent

        Dialog {
            id: cantOpenFileDialog

            title: "I can't open that file"
            text: "Files are stored in " + app.torrentsSavePath

            Button {
                text: "OK"
                onClicked: PopupUtils.close(cantOpenFileDialog)
            }
        }
    }

    Component {
        id: duplicateTorrentDialogComponent

        Dialog {
            id: duplicateTorrentDialog

            property string torrentName

            title: "Duplicate torrent"
            text: "The torrent \"" + torrentName + "\" already exists"

            Button {
                text: "OK"
                onClicked: PopupUtils.close(duplicateTorrentDialog)
            }
        }
    }
}
