import QtQuick 2.0
import Ubuntu.Components 1.0
import Ubuntu.Components.ListItems 1.0 as ListItem
import "Format.js" as Format
import "../Utils.js" as Utils
import com.nogzatalz.Downow 1.0

ListItem.Base {
    id: root
    height: Utils.gu(7)
    property DowNowTheme theme
    property /*FileEntry*/ var fileEntry

    progression: fileEntry.isCompleted

    Item {
        id: progressIndicator
        anchors {
            left: parent.left
            top: parent.top
            bottom: parent.bottom
            topMargin: units.gu(1)
            bottomMargin: units.gu(1)
        }
        width: height

        Rectangle {
            id: antiprogressCircle
            anchors.fill: parent
            color: UbuntuColors.warmGrey
            radius: width / 2
        }

        Pie {
            anchors.fill: parent
            color: {
                switch (fileEntry.state) {
                case FileEntry.Downloading: return theme.progressIndicatorDownloadingColor
                case FileEntry.Paused: return theme.progressIndicatorPausedColor
                case FileEntry.Done: return theme.progressIndicatorDoneColor
                default: return theme.progressIndicatorDownloadingColor
                }
            }
            percentsFilled: fileEntry.progress
        }

        FinishedIndicator {
            anchors.fill: parent
            isFinished: fileEntry.isCompleted

            front: Rectangle {
                id: whiteCircle
                anchors.centerIn: parent
                height: parent.height * 0.85
                width: height

                color: "white"
                radius: width / 2

                Label {
                    id: percents
                    text: (fileEntry.progress * 100).toFixed(0)
                    anchors.centerIn: parent
                    fontSize: "large"
                }

                Text {
                    id: percentsSign
                    anchors {
                        horizontalCenter: parent.horizontalCenter
                        bottom: parent.bottom
                        top: percents.bottom
                    }

                    text: "%"
                    fontSizeMode: Text.Fit
                    font.family: "ubuntu"
                    color: Theme.palette.normal.baseText
                    font.pixelSize: 100
                    horizontalAlignment: Text.AlignHCenter
                }
            }
        }
    }

    Column {
        anchors {
            right: parent.right
            left: progressIndicator.right
            verticalCenter: parent.verticalCenter
            leftMargin: units.gu(1)
        }
        spacing: units.gu(0.5)

        Text {
            id: name
            anchors {
                left: parent.left
                right: parent.right
            }
            font.family: "ubuntu"
            font.pixelSize: Utils.gu(2)

            elide: Text.ElideRight
            color: theme.torrentTitleColor

            text: fileEntry.name
        }

        Label {
            anchors {
                left: parent.left
                right: parent.right
            }
            fontSize: "medium"
            elide: Text.ElideRight
            color: theme.textColor

            text: {
                var timeLeft = fileEntry.timeLeftSec >= 0
                  ? Format.formatDuration(fileEntry.timeLeftSec) + " left"
                  : "";
                var downloadedBytesStr = Format.formatBytes(fileEntry.downloadedBytes);
                var totalBytesStr = Format.formatBytes(fileEntry.totalBytes);

                return (timeLeft !== "" ? timeLeft + " • " : "") +
                        downloadedBytesStr + "/" + totalBytesStr
            }
        }
    }
}
