import QtQuick 2.0
import Ubuntu.Components 1.0
import Ubuntu.Components.ListItems 1.0 as ListItem
import com.nogzatalz.Downow 1.0
import "Format.js" as Format
import "../Utils.js" as Utils

ListItem.Empty {
    id: root
    height: Utils.gu(9.5)
    property DowNowTheme theme
    property /*Torrent*/ var torrent

//    removable: true
//    confirmRemoval: true

    ProgressIndicator {
        id: progressIndicator

        anchors {
            left: parent.left
            top: parent.top
            bottom: parent.bottom
            margins: Utils.gu(1)
        }

        torrent: root.torrent
        theme: root.theme

        onResume: {
            torrent.resume()
        }
        onPause: {
            torrent.pause()
        }
    }

    Item {
        id: rightColumn

        anchors {
            left: progressIndicator.right
            top: parent.top
            bottom: parent.bottom
            right: parent.right
            leftMargin: Utils.gu(1)
            bottomMargin: Utils.gu(1)
            topMargin: Utils.gu(0.8)
        }

        Text {
            id: name
            anchors {
                left: parent.left
                right: parent.right
                rightMargin: Utils.gu(1)
                top: parent.top
            }
            font.family: "ubuntu"
            font.pixelSize: Utils.gu(2.3)

            elide: Text.ElideRight
            color: theme.torrentTitleColor

            text: torrent.name
        }

        Item {
            anchors {
                left: parent.left
                right: parent.right
                top: name.bottom
                bottom: parent.bottom
            }

            Column {
                id: text
                anchors {
                    left: parent.left
                    right: speedIndicators.left
                    bottom: parent.bottom
//                    verticalCenter: parent.verticalCenter
                }
                spacing: Utils.gu(0.3)

                Label {
                    id: downloadingMetadata
                    anchors {
                        left: parent.left
                        right: parent.right
                    }

                    text: "Downloading metadata"
                    visible: torrent.state == Torrent.Preparing
                }

                Column {
                    anchors {
                        left: parent.left
                        right: parent.right
                    }

                    spacing: parent.spacing
                    visible: torrent.state == Torrent.Downloading || torrent.state == Torrent.Paused

                    Label {
                        id: timeLeft
                        anchors {
                            left: parent.left
                            right: parent.right
                        }
                        fontSize: "medium"
                        elide: Text.ElideRight
                        color: theme.textColor

                        text: torrent.timeLeftSec >= 0
                              ? Format.formatDuration(torrent.timeLeftSec) + " left"
                              : ""
                    }

                    Label {
                        id: percentsLabel
                        anchors {
                            left: parent.left
                            right: parent.right
                        }
                        fontSize: "medium"
                        elide: Text.ElideRight
                        color: theme.textColor

                        text: {
                            var percents = 100 * torrent.downloadedBytes / torrent.totalBytes;
                            var downloadedBytesStr = Format.formatBytes(torrent.downloadedBytes);
                            var totalBytesStr = Format.formatBytes(torrent.totalBytes);
                            return percents.toFixed(0) + "% - " + downloadedBytesStr + "/" + totalBytesStr
                        }
                    }
                }
            }

            Column {
                id: speedIndicators
                anchors {
                    right: parent.right
//                    verticalCenter: parent.verticalCenter
                    bottom: parent.bottom
                    rightMargin: Utils.gu(0.5)
                }
                spacing: Utils.gu(0.5)

                SpeedIndicator {
                    anchors.right: parent.right
                    speedBytesPerSec: torrent.uploadSpeedBPS
                    icon: "../images/upload-icon.svg"
                    textColor: root.theme.torrentUploadSpeedTextColor
                }
                SpeedIndicator {
                    anchors.right: parent.right
                    speedBytesPerSec: torrent.downloadSpeedBPS
                    icon: "../images/download-icon.svg"
                    textColor: root.theme.torrentUploadSpeedTextColor
                    visible: torrent.state != Torrent.Seeding
                }
            }
        }
    }
}
