import QtQuick 2.0
import Ubuntu.Components 1.0
import Ubuntu.Components.ListItems 1.0 as ListItem
import com.nogzatalz.Downow 1.0
import Ubuntu.Components.Popups 1.0

Page {
    id: root
    title: i18n.tr("DowNow")

    signal openTorrentDetailsPage(Torrent torrent)

    property DowNowTheme theme
    property Action addAction
    property Action settingsAction

    property /*Torrent*/ var currentlyFocusedTorrent

    tools: ToolbarItems {
        ToolbarButton {
            action: addAction
        }
    }

    TorrentListModel {
        id: torrentsModel
        session: globalSession
    }

    Action {
        id: showInFileManagerAction
        text: "Show in file manager"
        onTriggered: root.openTorrentInFileManager(currentlyFocusedTorrent)
    }

    Action {
        id: deleteFilesAndRemoveAction
        text: "Remove and delete files"
        onTriggered: currentlyFocusedTorrent.removeAndDeleteFiles()
    }

    Action {
        id: removeAction
        text: "Remove"
        onTriggered: currentlyFocusedTorrent.remove()
    }

    function openTorrentMenu(torrentListItem, torrent) {
        root.currentlyFocusedTorrent = torrent
        PopupUtils.open(longTapOptionsComponent, torrentListItem)
    }

    function openTorrentInFileManager(torrent) {
        var success = Qt.openUrlExternally("file://" + torrent.savePath);
        if (!success) {
            PopupUtils.open(cantOpenFileManagerDialog);
        }
    }

    function openTorrent(torrent) {
        Qt.openUrlExternally("file://" + torrent.savePath + "/" + torrent.name)
    }

    flickable: listView

    ListView {
        id: listView
        anchors.fill: parent
        model: torrentsModel

        delegate: TorrentListItem {
            id: torrentListItem
            theme: root.theme
            torrent: model.torrent

            onClicked: root.openTorrentDetailsPage(torrent)
            onPressAndHold: root.openTorrentMenu(torrentListItem, torrent)

            /*
            MouseArea {
                anchors.fill: parent
                acceptedButtons: Qt.LeftButton | Qt.RightButton

                onPressAndHold: root.openTorrentMenu(torrentListItem, torrent)
                onClicked: {
                    if (mouse.button === Qt.RightButton) {
                        openTorrentMenu(torrentListItem, torrent)
                    }
                    else {
                        mouse.accepted = false
                    }
                }

                preventStealing: true
                propagateComposedEvents: true
            }
            */
        }
    }

    Column {
        visible: torrentsModel.count === 0
        anchors {
            verticalCenter: parent.verticalCenter
            left: parent.left
            right: parent.right
        }
        spacing: units.gu(1)

        Label {
            anchors {
                left: parent.left
                right: parent.right
            }

            text: "No torrents"
            fontSize: "large"
            font.bold: true
            horizontalAlignment: Text.AlignHCenter
        }
        Label {
            anchors {
                left: parent.left
                right: parent.right
            }

            text: "You can add torrents using the '+' button"
            fontSize: "medium"
            horizontalAlignment: Text.AlignHCenter
        }
    }

    Component {
        id: longTapOptionsComponent

        ActionSelectionPopover {
            id: longTapOptionsPopover
            actions: [
//                showInFileManagerAction,
                deleteFilesAndRemoveAction,
                removeAction
            ]
        }
    }

    Component {
        id: cantOpenFileManagerDialog
        Dialog {
            id: dialog
            title: "Can't open file manager"
            text: "I couldn't find an app to open the torrent's directory.\nTorrents are located in ~/.local/share/com.nogzatalz.downow/download."

            Button {
                text: "Got it"
                color: UbuntuColors.orange
                onClicked: PopupUtils.close(dialog)
            }
        }
    }
}
