import QtQuick 2.0
import Ubuntu.Components 1.1
import Ubuntu.Components.ListItems 1.0 as ListItem
import Ubuntu.Content 0.1
import Ubuntu.Components.Popups 1.0
import com.nogzatalz.Downow 1.0

Page {
    id: root
    property /*Torrent*/ var torrent
    property var selectedEntry
    property DowNowTheme theme
    title: "Details"

    signal done

    Action {
        id: removeAction
        text: "Remove"
        iconName: "delete"
        onTriggered: {
            // FIXME: When a torrent is removed using the dialog
            // we get a weird error and the app freeezes.
            // error: QQmlExpression: Attempted to evaluate an expression in an invalid context
            torrent.removeAndDeleteFiles()//PopupUtils.open(deleteDialogComponent)
        }
    }

    Connections {
        target: torrent
        onRemoved: root.done()
    }

    tools: ToolbarItems {
        ToolbarButton {
            action: removeAction
        }
    }

    flickable: null

    TorrentListItem {
        id: torrentListItem
        anchors {
            top: parent.top
            left: parent.left
            right: parent.right
        }

        theme: root.theme
        torrent: root.torrent
    }

    ListItem.Header {
        id: filesHeader
        anchors {
            top: torrentListItem.bottom
            left: parent.left
            right: parent.right
        }
        text: "Files"
    }

    ActivityIndicator {
        id: loadingFilesIndicator
        anchors {
            topMargin: units.gu(1)
            top: filesHeader.bottom
            horizontalCenter: parent.horizontalCenter
        }
        running: torrent.state === Torrent.Preparing
        visible: running
    }

    ListView {
        id: filesColumn
        anchors {
            top: filesHeader.bottom
            bottom: parent.bottom
            left: parent.left
            right: parent.right
        }

        clip: true
        visible: !loadingFilesIndicator.running

        model: FileEntriesModel {
            torrent: root.torrent
        }

        delegate: FileEntryListItem {
            fileEntry: model.fileEntry
            theme: root.theme

            onClicked: {
                if (!model.fileEntry.isCompleted) {
                    return;
                }
                model.fileEntry.open();
            }
        }

        footer: Label {
            id: howToOpenTorrentExplanation
            visible: filesColumn.visible
            anchors {
                left: parent.left
                right: parent.right
                margins: units.gu(1)
            }

            height: implicitHeight + units.gu(2)
            text: "You can open files by tapping them once they are done downloading"
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            wrapMode: Text.WordWrap
        }
    }

    Component {
        id: deleteDialogComponent
        Dialog {
            id: deleteDialog
            title: "Delete Torrent"
            text: "Are you sure you want to delete this torrent?"

            Button {
                text: "Delete and remove files"
                onClicked: {
                    PopupUtils.close(deleteDialog)
                    torrent.removeAndDeleteFiles()
                }
                color: UbuntuColors.red
            }

            Button {
                text: "Delete"
                onClicked: {
                    PopupUtils.close(deleteDialog)
                    torrent.removeAndDeleteFiles()
                }
                color: UbuntuColors.red
            }

            Button {
                text: "Cancel"
                onClicked: PopupUtils.close(deleteDialog)
                color: UbuntuColors.green
            }
        }
    }
}
